

library("abc")
require("abc.data")


canton <- "GE"
cases_deaths <- read.xlsx("cases_deaths.xlsx", sheetName="GE")
casedeath_dates <- as.Date(cases_deaths[,1])
data_cases <- cases_deaths[,2]
data_deaths <- cases_deaths[,3]
data_hosps <- cases_deaths[,4]
data_inhosp <- cases_deaths[,5]
data_inICU <- cases_deaths[,6]

trf <- function(arg) {
  return(arg)
}

target_hosp <- trf(data_hosps)
target_deaths <- trf(data_deaths)

modelsolution <- "stochastic"

sumstat_hosp <- matrix(ncol=56, nrow=10000)

sumstat_deaths <- matrix(ncol=56, nrow=10000)

toler_hosp <- rep(0.01, length=56)
toler_deaths <- rep(0.01, length=56)


#max_days <- 300 # total duration of simulation in days
epsilon <- 1/3.7 # E to Ip
mu_p <- 1/1.5 # Ip to Ia/Ips/Ims/Iss
mu <- 1/2.3 # Ia/Ips/Ims to recovery; Iss to hospitalization (assumed to be equal)
p_aC <- 0.5 # Probability to be asymptomatic: children
p_aA <- 0.5 # Probability to be asymptomatic: adults
p_aS <- 0.5 # Probability to be asymptomatic: seniors
p_msC <- 0 # If symptomatic, probability to have mild symptoms (but excluding paucisymptomatic): children
p_msA <-0.7 # ...
p_msS <- 0.6 # ...
p_ssC <- 0 # If symptomatic, probability to have severe symptoms: children
p_ssA <- 0.03 #0.1 #...
p_ssS <- 0.35 #0.2 # ...
p_ICUC <- 0 # If hospitalized, probability to go to ICU: children
p_ICUA <- 0.25 #0.36 # ...
p_ICUS <- 0.2 #0.2 # ...
lambdaHRC <- 0 # H to R: children
lambdaHRA <- 0.072 # ...
lambdaHRS <- 0.022 # ...
lambdaHDC <- 0
#lambdaHDA <- 2*0.0042 # ...
#lambdaHDS <- 4*0.014 # ...
lambdaICURC <- 0
lambdaICURA <- 0.05 # ...
lambdaICURS <- 0.036 # ...
lambdaICUDC <- 0
#lambdaICUDA <- 2*0.0074 # ...
#lambdaICUDS <- 4*0.029 # ...
rb <- 0.51 # relative infectiousness of prodomic, asymptomatic and paucisymptomatic individuals


#beta0 <- 0.8 # 0.74

relCC <- 2
relCA <- 0.5
relCS <- 0.2
relAS <- 0.4
relSS <- 1

#schoolCC <- 0.05
#schoolCA <- 0.8
#workAA <- 0.5
#shopAA <- 0.5 #0.5
#social1 <- 0.75
#social2 <- 0.75*0.65
restaurantAA <- 0.8

#inseed <- 5

lambdaHDA_prior <- c(0.0042, 3*0.0042)
lambdaHDS_prior <- c(0.014, 10*0.014)
lambdaICUDA_prior <- c(0.0074, 3*0.0074)
lambdaICUDS_prior <- c(0.029, 10*0.029)
start_date_fixed_prior <- seq(from=as.Date("2020/02/01"), to=as.Date("2020/02/25"), by=1)
beta0_prior <- c(0.5, 1)
schoolCC_prior <- c(0.02, 0.1)
schoolCA_prior <- c(0.5, 1)
workAA_prior <- c(0.2, 0.8)
shopAA_prior <- c(0.2, 0.8)
social1_prior <- c(0.5, 1)
social2_prior <- c(0.5, 0.8)
inseed_prior <- seq(from=1,20,by=1)

freeparams <- as.data.frame(matrix(ncol=10, nrow=10000)) 

freeparams[,1] <- runif(nrow(freeparams), lambdaHDA_prior[1], lambdaHDA_prior[2])
freeparams[,2] <- runif(nrow(freeparams), pmax(lambdaHDS_prior[1], freeparams[,1]), lambdaHDS_prior[2])
freeparams[,3] <- runif(nrow(freeparams), pmax(lambdaICUDA_prior[1], freeparams[,1]), lambdaICUDA_prior[2])
freeparams[,4] <- runif(nrow(freeparams), pmax(lambdaICUDS_prior[1], freeparams[,3]), lambdaICUDS_prior[2])
freeparams[,5] <- sample(start_date_fixed_prior, nrow(freeparams), replace=TRUE)
freeparams[,6] <- runif(nrow(freeparams), beta0_prior[1], beta0_prior[2])
freeparams[,7] <- runif(nrow(freeparams), schoolCC_prior[1], schoolCC_prior[2])
freeparams[,8] <- runif(nrow(freeparams), schoolCA_prior[1], schoolCA_prior[2])
freeparams[,9] <- runif(nrow(freeparams), workAA_prior[1], workAA_prior[2])
freeparams[,10] <- runif(nrow(freeparams), shopAA_prior[1], shopAA_prior[2]) 
freeparams[,11] <- runif(nrow(freeparams), social1_prior[1], social1_prior[2])
freeparams[,12] <- runif(nrow(freeparams), social2_prior[1], pmin(social2_prior[2],freeparams[,11]))
freeparams[,13] <- sample(inseed_prior, nrow(freeparams), replace=TRUE)


for (runnr in (1:10000)) {
  lambdaHDA <- freeparams[runnr,1]
  lambdaHDS <- freeparams[runnr,2]
  lambdaICUDA <- freeparams[runnr,3]
  lambdaICUDS <- freeparams[runnr,4]
  start_date_fixed <- freeparams[runnr,5]
  beta0 <- freeparams[runnr,6]
  schoolCC <- freeparams[runnr,7]
  schoolCA <- freeparams[runnr,8]
  workAA <- freeparams[runnr,9]
  shopAA <- freeparams[runnr,10]
  social1 <- freeparams[runnr,11]
  social2 <- freeparams[runnr,12]
  inseed <- freeparams[runnr,13]
  
  source("model_GE.R")
  start_relative <- as.numeric(as.Date("2020/02/25")-start_date_fixed+1)
  sumstat_hosp[runnr,] <- trf(newhosps_C[start_relative:(start_relative+55)]+newhosps_A[start_relative:(start_relative+55)]+newhosps_S[start_relative:(start_relative+55)])
  sumstat_deaths[runnr,] <- trf(newdeaths_C[start_relative:(start_relative+55)]+newdeaths_A[start_relative:(start_relative+55)]+newdeaths_S[start_relative:(start_relative+55)])
}


abcresult <- abc(target=c(target_hosp, target_deaths), param=freeparams, sumstat=cbind(sumstat_hosp, sumstat_deaths), tol=c(toler_hosp, toler_deaths), method="rejection")


i <- i+1

lambdaHDA <- as.numeric(abcresult$unadj.values[i,1])
lambdaHDS <- as.numeric(abcresult$unadj.values[i,2])
lambdaICUDA <- as.numeric(abcresult$unadj.values[i,3])
lambdaICUDS <- as.numeric(abcresult$unadj.values[i,4])
start_date_fixed <- as.Date(abcresult$unadj.values[i,5])
beta0 <- as.numeric(abcresult$unadj.values[i,6])
schoolCC <- as.numeric(abcresult$unadj.values[i,7])
schoolCA <- as.numeric(abcresult$unadj.values[i,8])
workAA <- as.numeric(abcresult$unadj.values[i,9])
shopAA <- as.numeric(abcresult$unadj.values[i,10])
social1 <- as.numeric(abcresult$unadj.values[i,11])
social2 <- as.numeric(abcresult$unadj.values[i,12])
inseed <- as.numeric(abcresult$unadj.values[i,13])

source("model_GE.R")
start_relative <- as.numeric(as.Date("2020/02/25")-start_date_fixed+1)
model_hosps <- trf(newhosps_C[start_relative:(start_relative+55)]+newhosps_A[start_relative:(start_relative+55)]+newhosps_S[start_relative:(start_relative+55)])
model_deaths <- trf(newdeaths_C[start_relative:(start_relative+55)]+newdeaths_A[start_relative:(start_relative+55)]+newdeaths_S[start_relative:(start_relative+55)])

plot(x=casedeath_dates, y=data_hosps, ylim=c(0,200))
lines(x=casedeath_dates, y=model_hosps)

plot(x=casedeath_dates, y=data_deaths, ylim=c(0,50))
lines(x=casedeath_dates, y=model_deaths)


##########







