### Fixed parameters


### Seasonality function

seasonfun <- function(startingdate, currentday, maxeffect) {
  zeroday <- as.Date("2019/11/01")
  currenttime <- as.numeric(startingdate+currentday-1-zeroday)
  currenttime_conv <- currenttime*pi/183
  convertedsin <- 0.5*sin(currenttime_conv) - 0.5
  return(1+(1-maxeffect)*convertedsin)
}



# Functions to determine numbers of transitions
# Deterministic variant: Transitions follow exactly from parameters (but rounded to full individuals)
if (modelsolution=="deterministic" | modelsolution=="combined") {
roundm <- function(pop, arg) { # This function is to determine the numbers of people exiting a compartment (before splitting t destinations)
  # pop: population to apply to; arg: number of people determined to transition 
  if (!is.finite(arg)) {
    arg <- 1e+40
  }
  if (round(arg)<pop) { # if the calculated number of people transitioning does not exceed the total number in the origin compartment...
    round(arg) # ...return the calculated number of people transitioning
  } else { # if the number of people transitioning exceeds the total number in the origin compartment...
    pop # ... return the entire origin compartment
  }
}



  roundp <- function(arg, prop) {  # This function will split the transitioned individuals into destinations
  # arg: number of people transitioning out of the origin compartment; prop: the proportion that go to the designated target
  if (!is.nan(prop)) { # unless prop is a NaN (i.e. 0/0)...
    round(prop*arg) # ... return the rounded proportion 
  } else { 
    0 
  }
  }
}
if (modelsolution=="stochastic") {
#Stochastic variant (comment out if you want to run the deterministic version): 
roundm <- function(pop, arg) { 
  probab <- arg/pop # Caclulate back the original transition rate (i.e. probability per day)
  if (pop>0) { # If the origin compartment is not empty...
    rbinom(1, as.integer(pop), probab) # ... sample the number of transitions from the binomial distribution
  } else {
    0
  }
}




roundp <- function(arg, prob) {
  if (arg>0) {
    rbinom(1, as.integer(arg), prob)
  } else {
    0
  }
}
}





#max_days <- 350 # total duration of simulation in days
#epsilon <- 1/3.7 # E to Ip
#mu_p <- 1/1.5 # Ip to Ia/Ips/Ims/Iss
#mu <- 1/2.3 # Ia/Ips/Ims to recovery; Iss to hospitalization (assumed to be equal)
#p_aC <- 0.5 # Probability to be asymptomatic: children
#p_aA <- 0.5 # Probability to be asymptomatic: adults
#p_aS <- 0.5 # Probability to be asymptomatic: seniors
#p_msC <- 0 # If symptomatic, probability to have mild symptoms (but excluding paucisymptomatic): children
#p_msA <-0.7 # ...
#p_msS <- 0.6 # ...
#p_ssC <- 0 # If symptomatic, probability to have severe symptoms: children
#p_ssA <- 0.03 #0.1 #...
#p_ssS <- 0.35 #0.2 # ...
#p_ICUC <- 0 # If hospitalized, probability to go to ICU: children
#p_ICUA <- 0.25 #0.36 # ...
#p_ICUS <- 0.2 #0.2 # ...
#lambdaHRC <- 0 # H to R: children
#lambdaHRA <- 0.072 # ...
#lambdaHRS <- 0.022 # ...
#lambdaHDC <- 0
#lambdaHDA <- 2*0.0042 # ...
#lambdaHDS <- 4*0.014 # ...
#lambdaICURC <- 0
#lambdaICURA <- 0.05 # ...
#lambdaICURS <- 0.036 # ...
#lambdaICUDC <- 0
#lambdaICUDA <- 2*0.0074 # ...
#lambdaICUDS <- 4*0.029 # ...
#rb <- 0.51 # relative infectiousness of prodomic, asymptomatic and paucisymptomatic individuals





##### Canton and population data



cantonpop <- cbind(c("AG","AI","AR","BE","BL","BS","FR","GE","GL","GR","JU","LU","NE","NW","OW","SG","SH","SO","SZ","TG","TI","UR","VD","VS","ZG","ZH","Total"),
                   1000*c(686, 16, 55, 1039, 289, 196, 322, 504, 41, 199, 74, 413, 176, 43, 38, 511, 82, 275, 160, 279, 351, 37, 805, 345, 128, 1539, 8604))




SC <- rep(0, length=max_days) # Susceptible children aged 0-<18
EC <- rep(0, length=max_days) # Exposed children
IpC <- rep(0, length=max_days) # Infectious children (prodomic phase)
IaC <- rep(0, length=max_days) # Infectious children (asymptomatic)
IpsC <- rep(0, length=max_days) # Infectious children (paucisymptomatic)
ImsC <- rep(0, length=max_days) # Infectious children (mild symptoms)
IssC <- rep(0, length=max_days) # Infectious children (severe symptoms)
HC <- rep(0, length=max_days) # Hospitalized children (not in ICU)
ICUC <- rep(0, length=max_days) # Children in ICU
RC <- rep(0, length=max_days) # Recovered children 
DC <- rep(0, length=max_days) # Died children
SA <- rep(0, length=max_days) # Same for adults as above (aged 18-<65)
EA <- rep(0, length=max_days)
IpA <- rep(0, length=max_days)
IaA <- rep(0, length=max_days)
IpsA <- rep(0, length=max_days)
ImsA <- rep(0, length=max_days)
IssA <- rep(0, length=max_days)
HA <- rep(0, length=max_days)
ICUA <- rep(0, length=max_days)
RA <- rep(0, length=max_days)
DA <- rep(0, length=max_days)
SS <- rep(0, length=max_days) # Same for seniors as above (aged 65 and above)
ES <- rep(0, length=max_days)
IpS <- rep(0, length=max_days)
IaS <- rep(0, length=max_days)
IpsS <- rep(0, length=max_days)
ImsS <- rep(0, length=max_days)
IssS <- rep(0, length=max_days)
HS <- rep(0, length=max_days)
ICUS <- rep(0, length=max_days)
RS <- rep(0, length=max_days)
DS <- rep(0, length=max_days)

# Indicators to fit into
newcases_C <- rep(0, length=max_days)
newcases_ms_C <- rep(0, length=max_days)
newhosps_C <- rep(0, length=max_days)
newICUs_C <- rep(0, length=max_days)
newdeaths_C <- rep(0, length=max_days)
newcases_A <- rep(0, length=max_days)
newcases_ms_A <- rep(0, length=max_days)
newhosps_A <- rep(0, length=max_days)
newICUs_A <- rep(0, length=max_days)
newdeaths_A <- rep(0, length=max_days)
newcases_S <- rep(0, length=max_days)
newcases_ms_S <- rep(0, length=max_days)
newhosps_S <- rep(0, length=max_days)
newICUs_S <- rep(0, length=max_days)
newdeaths_S <- rep(0, length=max_days)

Re <- rep(0, max_days)

#start_date_fixed <- as.Date("2020/02/05")
d1 <- min(max_days,as.Date("2020/03/05")-start_date_fixed) # first policy change: social distancing promoted, events cancelled
d2 <- min(max_days,as.Date("2020/03/16")-start_date_fixed) # second policy change: schools closed, home office recommended, most shops and services closed
d3 <- min(max_days,as.Date("2020/03/20")-start_date_fixed) # third policy change: some shops and services reopen
d4 <- min(max_days,as.Date("2020/04/27")-start_date_fixed) # fourth policy change: obligatory schools, most shops reopen
d5 <- min(max_days,as.Date("2020/05/11")-start_date_fixed) # fifth policy change: non-obligatory schools reopen
d6 <- min(max_days,as.Date("2020/06/08")-start_date_fixed) # sixth policy change: restaurants reopen, workplaces back to normal (anticipated)
d7 <- min(max_days,as.Date("2020/07/04")-start_date_fixed) # seventh change: school holidays start
d8 <- min(max_days,as.Date("2020/08/10")-start_date_fixed) # eigth change: school holidays end
d9 <- min(max_days,as.Date("2020/09/01")-start_date_fixed) # ninth policy change
d10 <- min(max_days,as.Date("2020/09/01")-start_date_fixed) # tenth policy change

#beta0 <- 0.8 # 0.74

#relCC <- 2
#relCA <- 0.5
#relCS <- 0.2
#relAS <- 0.4
#relSS <- 1

#schoolCC <- 0.05
#schoolCA <- 0.8
#workAA <- 0.5
#shopAA <- 0.5 #0.5
#social1 <- 0.75
#social2 <- 0.75*0.65
#restaurantAA <- 0.8

#inseed <- 5




c0 <- c(relCC,relCA,relCS,1,relAS,relSS) # baseline contact matrix: child-child, child-adult, child-senior, adult-adult, adult-senior, senior-senior (NOTE: assumed to be symmetric!!)
# interpretation "contacts per day" (but scale-free: so )
school <- c(schoolCC,schoolCA,1,1,1,1) # relative contacts after school closure (i.e. coefficient to apply to c0)
work <- c(1,1,1,workAA,1,1) # relaitve contacts after move to home ofice
event <- c(1,1,1,1,1,1) # relative contacts after prohibition of mass events
shop <- c(1,1,1,shopAA,shopAA,shopAA) # relative contacts after closing all non-essential shops and services
shop2 <- c(1,1,1,1-(1-shopAA)/2,1-(1-shopAA)/2,1-(1-shopAA)/2)
socialdist1 <- social1*c(1,1,0.8,1,0.8,0.8) #c(socialCC,socialCA,socialCS,socialAA,socialAS,socialSS) # relative contacts after recommedning social distancing
socialdist2 <- social2*c(1,1,0.8,1,0.8,0.8)
restaurant <- c(1,1,1, restaurantAA, restaurantAA,restaurantAA)
holiday <- c(schoolCC, schoolCA, 1, 1-(1-workAA)/2, 1, 1)
#holiday <- c(1,1,1,1,1,1)
#holiday <- c(0.5,0.5,0.5,0.5,0.5,0.5)
#tracA <- 0.1
#tracing <- c(1,1,1,tracA^2,tracA,1)
#tracing <- 0.48*c(1,1,1,1,1,1)
#tracS <- 1 #0.1
#tracing <- c(1,1,tracS,1,tracS,tracS^2)
c1 <- c0*event*socialdist1 #from 5.3.
c2 <- c0*school*event*shop*restaurant*socialdist1 # from 16.3.
c3 <- c0*school*work*event*shop*restaurant*socialdist2 # from 20.3.
c4 <- c0*school*work*event*shop2*restaurant*socialdist2 # from 27.4.
c5 <- c0*work*event*socialdist2*tracing # from 11.5.
c6 <- c0*event*socialdist1*tracing # from 8.6.
c7 <- c0*event*socialdist1*tracing*holiday # from 4.7.
c8 <- c0*socialdist1*tracing # from 10.8.
c9 <- c0*socialdist1*tracing
c10 <- c0*socialdist1*tracing

#######

contactCC <- c(rep(c0[1], length=d1), rep(c1[1], length=d2-d1), rep(c2[1], length=d3-d2), rep(c3[1], length=d4-d3), rep(c4[1], length=d5-d4), rep(c5[1], length=d6-d5), rep(c6[1], length=d7-d6), rep(c7[1], length=d8-d7), rep(c8[1], length=d9-d8), rep(c9[1], length=d10-d9), rep(c10[1], length=max_days-d10))
contactCA <- c(rep(c0[2], length=d1), rep(c1[2], length=d2-d1), rep(c2[2], length=d3-d2), rep(c3[2], length=d4-d3), rep(c4[2], length=d5-d4), rep(c5[2], length=d6-d5), rep(c6[2], length=d7-d6), rep(c7[2], length=d8-d7), rep(c8[2], length=d9-d8), rep(c9[2], length=d10-d9), rep(c10[2], length=max_days-d10))
contactCS <- c(rep(c0[3], length=d1), rep(c1[3], length=d2-d1), rep(c2[3], length=d3-d2), rep(c3[3], length=d4-d3), rep(c4[3], length=d5-d4), rep(c5[3], length=d6-d5), rep(c6[3], length=d7-d6), rep(c7[3], length=d8-d7), rep(c8[3], length=d9-d8), rep(c9[3], length=d10-d9), rep(c10[3], length=max_days-d10))
contactAA <- c(rep(c0[4], length=d1), rep(c1[4], length=d2-d1), rep(c2[4], length=d3-d2), rep(c3[4], length=d4-d3), rep(c4[4], length=d5-d4), rep(c5[4], length=d6-d5), rep(c6[4], length=d7-d6), rep(c7[4], length=d8-d7), rep(c8[4], length=d9-d8), rep(c9[4], length=d10-d9), rep(c10[4], length=max_days-d10))
contactAS <- c(rep(c0[5], length=d1), rep(c1[5], length=d2-d1), rep(c2[5], length=d3-d2), rep(c3[5], length=d4-d3), rep(c4[5], length=d5-d4), rep(c5[5], length=d6-d5), rep(c6[5], length=d7-d6), rep(c7[5], length=d8-d7), rep(c8[5], length=d9-d8), rep(c9[5], length=d10-d9), rep(c10[5], length=max_days-d10))
contactSS <- c(rep(c0[6], length=d1), rep(c1[6], length=d2-d1), rep(c2[6], length=d3-d2), rep(c3[6], length=d4-d3), rep(c4[6], length=d5-d4), rep(c5[6], length=d6-d5), rep(c6[6], length=d7-d6), rep(c7[6], length=d8-d7), rep(c8[6], length=d9-d8), rep(c9[6], length=d10-d9), rep(c10[6], length=max_days-d10))

betaCC <- beta0*contactCC # infectiousness per day in child-child contacts
betaCA <- beta0*contactCA # ...
betaCS <- beta0*contactCS # ...
betaAA <- beta0*contactAA # ...
betaAS <- beta0*contactAS # ...
betaSS <- beta0*contactSS # ...

inpop <- as.numeric(cantonpop[which(cantonpop[,1]==canton),2]) # Initial total population
inseed_C <- round(inseed/5) # Initial number of children exposed
inseed_A <- round(3*inseed/5) # Initial number of adults exposed
inseed_S <- round(inseed/5) # Initial number of seniors exposed 
prop_C <- 0.20 # Proportion of total population who are children
prop_S <- 0.18 # Proportion of total population who are seniors
prop_A <- 1-prop_C-prop_S
SC[1] <- prop_C*inpop - inseed_C # Initial conditions for non-empty compartments on first day
EC[1] <- inseed_C
SA[1] <- prop_A*inpop - inseed_A
EA[1] <- inseed_A
SS[1] <- prop_S*inpop - inseed_S
ES[1] <- inseed_S

# Main model: loop over days
for (day in (2:max_days)) {
  
  if (modelsolution=="combined" & start_date_fixed + day==as.Date("2020/05/10")) {
    roundm <- function(pop, arg) { 
      probab <- arg/pop # Caclulate back the original transition rate (i.e. probability per day)
      if (pop>0) { # If the origin compartment is not empty...
        rbinom(1, as.integer(pop), probab) # ... sample the number of transitions from the binomial distribution
      } else {
        0
      }
    }
    
    
    
    
    roundp <- function(arg, prob) {
      if (arg>0) {
        rbinom(1, as.integer(arg), prob)
      } else {
        0
      }
    }
  }
  
  
  
  # First, calculate the number of people transitioning
  SCtoEC <- roundm(SC[day-1],SC[day-1]*seasonfun(start_date_fixed, day, max_eff)*(betaCC[day-1]*(rb*IpC[day-1]+rb*IaC[day-1]+rb*IpsC[day-1]+ImsC[day-1]+IssC[day-1])/(SC[day-1]+EC[day-1]+IpC[day-1]+IaC[day-1]+IpsC[day-1]+ImsC[day-1]+IssC[day-1]+RC[day-1]) +
                                          betaCA[day-1]*(rb*IpA[day-1]+rb*IaA[day-1]+rb*IpsA[day-1]+ImsA[day-1]+IssA[day-1])/(SA[day-1]+EA[day-1]+IpA[day-1]+IaA[day-1]+IpsA[day-1]+ImsA[day-1]+IssA[day-1]+RA[day-1]) +
                                          betaCS[day-1]*(rb*IpS[day-1]+rb*IaS[day-1]+rb*IpsS[day-1]+ImsS[day-1]+IssS[day-1])/(SS[day-1]+ES[day-1]+IpS[day-1]+IaS[day-1]+IpsS[day-1]+ImsS[day-1]+IssS[day-1]+RC[day-1])))
  SAtoEA <- roundm(SA[day-1],SA[day-1]*seasonfun(start_date_fixed, day, max_eff)*(betaCA[day-1]*(rb*IpC[day-1]+rb*IaC[day-1]+rb*IpsC[day-1]+ImsC[day-1]+IssC[day-1])/(SC[day-1]+EC[day-1]+IpC[day-1]+IaC[day-1]+IpsC[day-1]+ImsC[day-1]+IssC[day-1]+RC[day-1]) +
                                          betaAA[day-1]*(rb*IpA[day-1]+rb*IaA[day-1]+rb*IpsA[day-1]+ImsA[day-1]+IssA[day-1])/(SA[day-1]+EA[day-1]+IpA[day-1]+IaA[day-1]+IpsA[day-1]+ImsA[day-1]+IssA[day-1]+RA[day-1]) +
                                          betaAS[day-1]*(rb*IpS[day-1]+rb*IaS[day-1]+rb*IpsS[day-1]+ImsS[day-1]+IssS[day-1])/(SS[day-1]+ES[day-1]+IpS[day-1]+IaS[day-1]+IpsS[day-1]+ImsS[day-1]+IssS[day-1]+RC[day-1])))
  SStoES <- roundm(SS[day-1],SS[day-1]*seasonfun(start_date_fixed, day, max_eff)*(betaCS[day-1]*(rb*IpC[day-1]+rb*IaC[day-1]+rb*IpsC[day-1]+ImsC[day-1]+IssC[day-1])/(SC[day-1]+EC[day-1]+IpC[day-1]+IaC[day-1]+IpsC[day-1]+ImsC[day-1]+IssC[day-1]+RC[day-1]) +
                                          betaAS[day-1]*(rb*IpA[day-1]+rb*IaA[day-1]+rb*IpsA[day-1]+ImsA[day-1]+IssA[day-1])/(SA[day-1]+EA[day-1]+IpA[day-1]+IaA[day-1]+IpsA[day-1]+ImsA[day-1]+IssA[day-1]+RA[day-1]) +
                                          betaSS[day-1]*(rb*IpS[day-1]+rb*IaS[day-1]+rb*IpsS[day-1]+ImsS[day-1]+IssS[day-1])/(SS[day-1]+ES[day-1]+IpS[day-1]+IaS[day-1]+IpsS[day-1]+ImsS[day-1]+IssS[day-1]+RC[day-1])))
  ECtoIpC <- roundm(EC[day-1],epsilon*EC[day-1])
  EAtoIpA <- roundm(EA[day-1],epsilon*EA[day-1])
  EStoIpS <- roundm(ES[day-1],epsilon*ES[day-1])
  IpCtoIsC <- roundm(IpC[day-1],mu_p*IpC[day-1]) # Note that this is the number of people exiting IpC: this will be later split to IaC, IpsC, ImsC, IssC
  IpAtoIsA <- roundm(IpA[day-1],mu_p*IpA[day-1])
  IpStoIsS <- roundm(IpS[day-1],mu_p*IpS[day-1])
  IsCsymp <- roundp(IpCtoIsC, 1-p_aC) # Take from IpCtoIsC the proportion who will be symptomatic...
  IsAsymp <- roundp(IpAtoIsA, 1-p_aA)
  IsSsymp <- roundp(IpStoIsS, 1-p_aS)
  IsCsev <- roundp(IsCsymp, p_ssC) # ... and of those symptomatic, who will have severe symptoms..
  IsAsev <- roundp(IsAsymp, p_ssA)
  IsSsev <- roundp(IsSsymp, p_ssS)
  IsCmsy <- roundp(IsCsymp-IsCsev, p_msC/(1-p_ssC)) # ... and mild symptoms
  IsAmsy <- roundp(IsAsymp-IsAsev, p_msA/(1-p_ssA))
  IsSmsy <- roundp(IsSsymp-IsSsev, p_msS/(1-p_ssS))
  IaCtoRC <- roundm(IaC[day-1], mu*IaC[day-1])
  IaAtoRA <- roundm(IaA[day-1], mu*IaA[day-1])
  IaStoRS <- roundm(IaS[day-1], mu*IaS[day-1])
  IpsCtoRC <- roundm(IpsC[day-1], mu*IpsC[day-1])
  IpsAtoRA <- roundm(IpsA[day-1], mu*IpsA[day-1])
  IpsStoRS <- roundm(IpsS[day-1], mu*IpsS[day-1])
  ImsCtoRC <- roundm(ImsC[day-1], mu*ImsC[day-1])
  ImsAtoRA <- roundm(ImsA[day-1], mu*ImsA[day-1])
  ImsStoRS <- roundm(ImsS[day-1], mu*ImsS[day-1])
  IssCtohospC <- roundm(IssC[day-1], mu*IssC[day-1])
  IssAtohospA <- roundm(IssA[day-1], mu*IssA[day-1])
  IssStohospS <- roundm(IssS[day-1], mu*IssS[day-1])
  hospCICU <- roundp(IssCtohospC, p_ICUC)
  hospAICU <- roundp(IssAtohospA, p_ICUA)
  hospSICU <- roundp(IssStohospS, p_ICUS)
  HCtoRorD <- roundm(HC[day-1], (lambdaHRC+lambdaHDC)*HC[day-1])
  HAtoRorD <- roundm(HA[day-1], (lambdaHRA+lambdaHDA)*HA[day-1])
  HStoRorD <- roundm(HS[day-1], (lambdaHRS+lambdaHDS)*HS[day-1])
  ICUCtoRorD <- roundm(ICUC[day-1], (lambdaICURC+lambdaICUDC)*ICUC[day-1])
  ICUAtoRorD <- roundm(ICUA[day-1], (lambdaICURA+lambdaICUDA)*ICUA[day-1])
  ICUStoRorD <- roundm(ICUS[day-1], (lambdaICURS+lambdaICUDS)*ICUS[day-1])
  HRDCD <- roundp(HCtoRorD, lambdaHDC/(lambdaHDC+lambdaHRC))
  HRDAD <- roundp(HAtoRorD, lambdaHDA/(lambdaHDA+lambdaHRA))
  HRDSD <- roundp(HStoRorD, lambdaHDS/(lambdaHDS+lambdaHRS))
  ICURDCD <- roundp(ICUCtoRorD, lambdaICUDC/(lambdaICUDC+lambdaICURC))
  ICURDAD <- roundp(ICUCtoRorD, lambdaICUDA/(lambdaICUDA+lambdaICURA))
  ICURDSD <- roundp(ICUCtoRorD, lambdaICUDS/(lambdaICUDS+lambdaICURS))
  
  # Next, update each compartment with the help of the variables defined above
  # NOTE the limitations: no transitions between age groups or background mortality (negligible within a short time period)
  SC[day] <- SC[day-1] - SCtoEC
  EC[day] <- EC[day-1] + SCtoEC - ECtoIpC
  IpC[day] <- IpC[day-1] + ECtoIpC - IpCtoIsC
  IaC[day] <- IaC[day-1] + (IpCtoIsC-IsCsymp) - IaCtoRC
  IpsC[day] <- IpsC[day-1] + (IsCsymp-IsCsev-IsCmsy) - IpsCtoRC
  ImsC[day] <- ImsC[day-1] + IsCmsy - ImsCtoRC
  IssC[day] <- IssC[day-1] + IsCsev - IssCtohospC
  HC[day] <- HC[day-1] + (IssCtohospC-hospCICU) - HCtoRorD
  ICUC[day] <- ICUC[day-1] + hospCICU - ICUCtoRorD
  RC[day] <- RC[day-1] + IaCtoRC + IpsCtoRC + ImsCtoRC + (HCtoRorD-HRDCD) + (ICUCtoRorD-ICURDCD)
  DC[day] <- DC[day-1] + HRDCD + ICURDCD
  
  SA[day] <- SA[day-1] - SAtoEA
  EA[day] <- EA[day-1] + SAtoEA - EAtoIpA
  IpA[day] <- IpA[day-1] + EAtoIpA - IpAtoIsA
  IaA[day] <- IaA[day-1] + (IpAtoIsA-IsAsymp) - IaAtoRA
  IpsA[day] <- IpsA[day-1] + (IsAsymp-IsAsev-IsAmsy) - IpsAtoRA
  ImsA[day] <- ImsA[day-1] + IsAmsy - ImsAtoRA
  IssA[day] <- IssA[day-1] + IsAsev - IssAtohospA
  HA[day] <- HA[day-1] + (IssAtohospA-hospAICU) - HAtoRorD
  ICUA[day] <- ICUA[day-1] + hospAICU - ICUAtoRorD
  RA[day] <- RA[day-1] + IaAtoRA + IpsAtoRA + ImsAtoRA + (HAtoRorD-HRDAD) + (ICUAtoRorD-ICURDAD)
  DA[day] <- DA[day-1] + HRDAD + ICURDAD
  
  SS[day] <- SS[day-1] - SStoES
  ES[day] <- ES[day-1] + SStoES - EStoIpS
  IpS[day] <- IpS[day-1] + EStoIpS - IpStoIsS
  IaS[day] <- IaS[day-1] + (IpStoIsS-IsSsymp) - IaStoRS
  IpsS[day] <- IpsS[day-1] + (IsSsymp-IsSsev-IsSmsy) - IpsStoRS
  ImsS[day] <- ImsS[day-1] + IsSmsy - ImsStoRS
  IssS[day] <- IssS[day-1] + IsSsev - IssStohospS
  HS[day] <- HS[day-1] + (IssStohospS-hospSICU) - HStoRorD
  ICUS[day] <- ICUS[day-1] + hospSICU - ICUStoRorD
  RS[day] <- RS[day-1] + IaStoRS + IpsStoRS + ImsStoRS + (HStoRorD-HRDSD) + (ICUStoRorD-ICURDSD)
  DS[day] <- DS[day-1] + HRDSD + ICURDSD
  
  # Finally update the indicators
  
  
  newcases_C[day] <- ECtoIpC 
  newcases_ms_C[day] <- IsCmsy  + IsCsev 
  newhosps_C[day] <- IssCtohospC 
  newICUs_C[day] <- hospCICU 
  newdeaths_C[day] <- HRDCD + ICURDCD 
  newcases_A[day] <-  EAtoIpA 
  newcases_ms_A[day] <- IsAmsy + IsAsev 
  newhosps_A[day] <- IssAtohospA 
  newICUs_A[day] <- hospAICU 
  newdeaths_A[day] <- HRDAD + ICURDAD 
  newcases_S[day] <- EStoIpS
  newcases_ms_S[day] <- IsSmsy + IsSsev
  newhosps_S[day] <- IssStohospS
  newICUs_S[day] <-  hospSICU
  newdeaths_S[day] <- HRDSD + ICURDSD
  
  Re[day] <- 3.8*((SCtoEC+SAtoEA+SStoES)/(IpC[day-1]+IpA[day-1]+IpS[day-1]+IaC[day-1]+IaA[day-1]+IaS[day-1]+IpsC[day-1]+IpsA[day-1]+IpsS[day-1]+ImsC[day-1]+ImsA[day-1]+ImsS[day-1]+IssC[day-1]+IssA[day-1]+IssS[day-1]))
  
  
}
outcome_end <- 70

#######

#data_hosps_A <- foph2_hosp[,4]
#data_hosps_S <- foph2_hosp[,5]
#data_ICUs_A <- foph2_hosp[,7]
#data_ICUs_S <- foph2_hosp[,8]
#par(mfrow=c(2,2))
#par(col="gray")
#plot(seq(from=min_date, to=max_date, by=1), data_hosps_A, xlim=c(start_date_fixed, start_date_fixed+outcome_end), ylim=c(0, 60))  
#lines(seq(from=start_date_fixed, to=start_date_fixed+outcome_end-1, by=1), newhosps_A[(1:outcome_end)]) 

#plot(seq(from=min_date, to=max_date, by=1), data_hosps_S, xlim=c(start_date_fixed, start_date_fixed+outcome_end), ylim=c(0, 60))  
#lines(seq(from=start_date_fixed, to=start_date_fixed+outcome_end-1, by=1), newhosps_S[(1:outcome_end)]) 

#plot(seq(from=min_date, to=max_date, by=1), data_ICUs_A, xlim=c(start_date_fixed, start_date_fixed+outcome_end), ylim=c(0, 30))  
#lines(seq(from=start_date_fixed, to=start_date_fixed+outcome_end-1, by=1), newICUs_A[(1:outcome_end)]) 

#plot(seq(from=min_date, to=max_date, by=1), data_ICUs_S, xlim=c(start_date_fixed, start_date_fixed+outcome_end), ylim=c(0, 30))  
#lines(seq(from=start_date_fixed, to=start_date_fixed+outcome_end-1, by=1), newICUs_S[(1:outcome_end)]) 



